@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2009, 2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2009-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -31,7 +31,7 @@ public:
 	/**
 	 * @brief destructor
 	 */
-    ~KGpgPrimaryUid() override;
+	~KGpgPrimaryUid() override = default;
 
 protected:
 	bool nextLine(const QString &line) override;
